# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2019-02-27 20:01
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('medlem', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='giro',
            name='konto',
            field=models.CharField(choices=[('A', 'Medlemskonto (KID)'), ('M', 'Medlemskonto'), ('K', 'Kassa'), ('B', 'Brukskonto'), ('S', 'SMS'), ('V', 'Vipps')], default='M', max_length=1, verbose_name='Konto'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='betalt_av',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='betalar_for', to='medlem.Medlem'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='user',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL, verbose_name='innloggingsbrukar'),
        ),
        migrations.AlterField(
            model_name='medlem',
            name='verva_av',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='har_verva', to='medlem.Medlem'),
        ),
        migrations.AlterField(
            model_name='rolle',
            name='rolletype',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='medlem.Rolletype'),
        ),
    ]
